#!/bin/bash
#    $1 - Image Version (digit)
#    $2 - Image Description
#    $3 - directory where locate rootfs	
#    $4 - stb model
#    $5 - file_profile	

R='\033[1;31m'  # RED
G='\033[0;32m'  # GREEN
Y='\033[0;33m'  # YELLOW
CL='\E[0m'      # End color

##########################
if [[ $# < 2 ]]; then
    echo -e ""
    echo -e $Y"Usage:"$CL
    echo -e $Y"    $0 <version_number> \"<"description">\" <path_to_rootfs> <model_name> <profile>"$CL
    echo -e ""
    echo -e $Y"    The <version_number> must be a number (3 digits)"$CL
    echo -e $Y"    The <"description"> should be escaped, 'Spaces' are not allowed!"$CL
    echo -e $Y"    The <model_name> should be the same as the Model Name of STB"$CL
    echo -e $Y"    The Model Name can be viewed in System Recovery Utility > Device Information > Model"$CL
    echo -e $Y"    or in System Settings > Device Info > Model"$CL
    echo -e ""
    echo -e $Y"For example:"$CL
    echo -e $Y"    $0 220 \""Test_image"\" ../../420/rootfs-2.20.01/ MAG420 ./img_make.profile.mag420"$CL
    echo -e ""
    exit 0
fi
##########################

if [ "$5" != "" ]; then 
  . $5
fi

if [ "$1" == "" ]; then 
    img_ver=$IMAGE_VERSION 
else 
    img_ver=$1 
fi

if [ "$2" == "" ]; then
    img_desc=$IMAGE_DESCRIPTION
else
    img_desc=$2
fi

if [ "$3" == "" ]; then
    root_path=$ROOTFS_PATH     
else
    root_path=$3
fi

if [ "$KERNEL_PATH" == "" ]; then
    KERNEL_PATH=./uImzlib.img
fi

if [ ! -f $root_path/etc/VerUpdateAPI.conf ] ; then
    echo -e $R"\nUpdate API version is not defined!!!\n"$CL
    exit 1;
fi

tput sgr0

verUpdateAPI=`cat $root_path/etc/VerUpdateAPI.conf | awk '{printf  $1; exit;}'`
echo -e $Y"Make rootfs image $root_path"$CL
./mk_rfs.sh $root_path

MODELN=$4

# Append digital signature
echo -e $Y"Append digital signature MAG200_OP_KEY=$MAG200_OP_KEY"$CL
./mksign.sh ./${MODELN,,}/out/sumsubfsnone.img ./sumsubfsnone.img.sign $HASH_TYPE

# Make One Image
./make_imageupdate.sh ./${MODELN,,}/out/imageupdate $KERNEL_PATH ./sumsubfsnone.img.sign $img_ver $img_desc $4 $verUpdateAPI $HASH_TYPE
rm -f ./sumsubfsnone.img.sign

tput sgr0
