#!/bin/bash

# Parameters:
# 	$1 - name file of kernel prepared mkimage
# 	$2 - name file of result
#       $3 - SHA256 if required

R='\033[1;31m'  # RED
G='\033[0;32m'  # GREEN
Y='\033[0;33m'  # YELLOW
CL='\E[0m'      # End color


check_user_id() {

    if [ -z $MAG200_OP_KEY ]; then
        echo " "
        echo -e $Y"    You must set envirment variable MAG200_OP_KEY"$CL
        echo -e $Y"        example: export MAG200_OP_KEY=STB_PUBLIC"$CL
        echo " "
        exit 1
    fi
    gpg --list-keys $MAG200_OP_KEY > tmp.test
    param="if((\$1 == \"uid\")&&(\$2 == \"$MAG200_OP_KEY\")) {print \$2; exit; } "
    present_key=`awk {"$param"}  tmp.test`
    if [ -z "$present_key" ]; then
        echo ""
        echo -e $R"     Error: Key with USER_ID $MAG200_OP_KEY not present in gpg"$CL
        echo -e $R"            Append in gpg default public key with USER_ID - STB_PUBLIC:"$CL
        echo -e $R"            gpg --import ./stb_secbin.key "$CL
        echo ""
	rm -f tmp.test
        return 1
    fi
    rm -f tmp.test
    return 0
}

check_user_id
if [ "$?" -ne "0" ]; then
    exit 1
fi

rm   -f $1.sig
if [ "$3" = "SHA256" ] ; then
    gpg --force-v3-sigs -u $MAG200_OP_KEY --digest-algo=sha256 --detach-sign $1
else
    gpg --force-v3-sigs -u $MAG200_OP_KEY --detach-sign $1
fi

if [ "$?" -ne "0" ]; then
 echo -e $R"Error make digital signature."$CL
 rm -f $1.sig
 exit 1
fi
cat $1 > $2
./dsign -a -i $1.sig $2
if [ "$?" -ne "0" ]; then
 echo -e $R"Error append digital signature."$CL
 rm -f $1.sig $2
 exit 1
fi
rm  -f $1.sig 
echo -e $Y"File"$CL $Y"$2"$CL $G"create - successfully!!!"$CL

tput sgr0